@@ -1,4 +1,4 @@
-from settings.base import *
+from wheelcms_project.settings.base import *
 
 INSTALLED_APPS += ("wheelcms_axle.tests", )
 
